Document

Exhibit 32
CERTIFICATION
In connection with the periodic report of The Clorox Company (the “Company”) on Form 10-K for the period ended June 30, 2022, as filed with the Securities and Exchange Commission (the “Report”), we, Linda Rendle, Chief Executive Officer of the Company, and Kevin B. Jacobsen, Executive Vice President – Chief Financial Officer of the Company, hereby certify as of the date hereof, solely for purposes of Title 18, Chapter 63, Section 1350 of the United States Code, that to our knowledge:
(1)the Report fully complies with the requirements of Section 13(a) or 15(d), as applicable, of the Securities Exchange Act of 1934, and
(2)the information contained in the Report fairly presents, in all material respects, the financial condition and results of operations of the Company at the dates and for the periods indicated.
This Certification has not been, and shall not be deemed, “filed” with the Securities and Exchange Commission.
Date: August 10, 2022

/s/ Linda Rendle |
Linda Rendle |
Chief Executive Officer
/s/ Kevin B. Jacobsen |
Kevin B. Jacobsen |
Executive Vice President – Chief Financial Officer